/*
			      Animated Icon
 */

#ifndef ANIMICON_H
#define ANIMICON_H

#include <gtk/gtk.h>


extern GtkWidget *AnimIconNew(gint width, gint height);
void AnimIconSetFromXPMDataList(
	GtkWidget *w, GList *data_list, gulong interval
);
void AnimIconSetRepeating(GtkWidget *w, gboolean repeating);

extern gint AnimIconFrames(GtkWidget *w);
extern gint AnimIconFrame(GtkWidget *w);
extern gboolean AnimIconIsPlaying(GtkWidget *w);
extern void AnimIconSeek(GtkWidget *w, gint frame);
extern void AnimIconPause(GtkWidget *w);
extern void AnimIconPlay(GtkWidget *w);




#endif	/* ANIMICON_H */
